Artifact class

Constructors

Artifact({required String path, required DateTime createdAt, required DateTime updatedAt, String? id, String? sourcePath, String? sourceContext, String? context, String? mimeType, Map<String, dynamic>? metadata, String? author, String? rootPath, DateTime? deletedAt})
Artifact.fromJson(Map<String, dynamic> json)
factory

Properties

author String?
final
context String?
final
createdAt DateTime
final
deletedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
metadata Map<String, dynamic>?
final
mimeType String?
final
path String
final
rootPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceContext String?
final
sourcePath String?
final
updatedAt DateTime
final

Methods

copyWith({String? id, String? sourcePath, String? sourceContext, String? path, DateTime? createdAt, DateTime? updatedAt, String? context, String? mimeType, Map<String, dynamic>? metadata, String? author, String? rootPath, DateTime? deletedAt}) Artifact
deleted() Artifact
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
unDeleted() Artifact

Operators

operator ==(Object other) bool
The equality operator.
inherited