Job class

Constructors

Job({required String name, required DateTime createdAt, required DateTime updatedAt, required JobStatus status, required Artifact artifact, String? id, String? error})
Job.fromJson(Map<String, dynamic> json)
factory

Properties

artifact Artifact
final
createdAt DateTime
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status JobStatus
final
updatedAt DateTime
final

Methods

copyWith({String? id, String? name, DateTime? createdAt, DateTime? updatedAt, JobStatus? status, String? error, Artifact? artifact}) Job
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited