JobsService class
Constructors
-
JobsService({required Repository<
Job> repository})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
repository
→ Repository<
Job> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
String name, Artifact artifact) → Future< Job> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateStatus(
String id, JobStatus status, {String? error}) → Future< Job>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited