RepositoryArtifactFirestore class
Constructors
- RepositoryArtifactFirestore({required String projectId, required FirestoreApi firestore, String? database, String? path})
Properties
- collectionId → String
-
no setterinherited
- collectionParentPath → String
-
no setterinherited
- documentsPath → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Artifact item) → Future< Artifact> -
inherited
-
addAll(
Object items) → Future< Iterable< Artifact> > -
inherited
-
addWithId(
String id, Artifact item) → Future< Artifact> -
inherited
-
delete(
String id) → Future< void> -
inherited
-
deleteAll(
Iterable< String> ids) → Future<void> -
inherited
-
get(
String id) → Future< Artifact> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
{Query query = const AllQuery()}) → Future< List< Artifact> > -
inherited
-
stream(
String id) → Stream< Artifact> -
inherited
-
streamQuery(
{Query query = const AllQuery()}) → Stream< List< Artifact> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, Artifact updater(Artifact)) → Future< Artifact> -
inherited
-
updateAll(
Iterable< IdentifedObject< items) → Future<Artifact> >Iterable< Artifact> > -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited