RepositoryJobsFirestore class
Constructors
- RepositoryJobsFirestore({required String projectId, required FirestoreApi firestore, String? database, String? path})
Properties
- collectionId → String
-
no setterinherited
- collectionParentPath → String
-
no setterinherited
- documentsPath → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Job item) → Future< Job> -
inherited
-
addAll(
Object items) → Future< Iterable< Job> > -
inherited
-
addWithId(
String id, Job item) → Future< Job> -
inherited
-
delete(
String id) → Future< void> -
inherited
-
deleteAll(
Iterable< String> ids) → Future<void> -
inherited
-
get(
String id) → Future< Job> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
{Query query = const AllQuery()}) → Future< List< Job> > -
inherited
-
stream(
String id) → Stream< Job> -
inherited
-
streamQuery(
{Query query = const AllQuery()}) → Stream< List< Job> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, Job updater(Job)) → Future< Job> -
inherited
-
updateAll(
Iterable< IdentifedObject< items) → Future<Job> >Iterable< Job> > -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited