ArtifactService class
Constructors
-
ArtifactService(Repository<
Artifact> _artifactRepository)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createArtifact(
{required String path, required String mimeType, String? context, Map< String, dynamic> ? metadata}) → Future<Artifact> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateArtifact(
{required String artifactId, Map< String, dynamic> metadata = const {}, String? context}) → Future<Artifact>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited