DataProcessFirebaseStorage class abstract
- Implemented types
Constructors
-
DataProcessFirebaseStorage({required String bucket, required StorageApi storage, required Repository<
Artifact> artifactRepository, required JobsService jobsService})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setterinherited
- outputMimeType → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getArtifact(
String path) → Future< Artifact?> -
logItem(
String outputPath, {Artifact? sourceArtifact}) → Future< Artifact> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
String inputPath, String outputPath) → Future< void> -
override
-
processMedia(
Media input, Artifact sourceArtifact) → Future< File?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited